@@ -15,11 +15,8 @@ struct logdata {
 	gid_t gid;
 };
 
-void sockettabs_free();
-void logtabs_free();
-void argvtabs_free();
-void rlimittabs_free();
-void services_free();
+void sockettabs_free(void);
+void services_free(void);
 
 void rlp_cleanup(struct rl_cleanup *rlc);
 
